@@ -4,8 +4,12 @@ use strict;
 use base 'Exporter';
 
 @Chart::Clicker::Drawing::EXPORT_OK = qw();
-@Chart::Clicker::Drawing::EXPORT_OK = qw($CC_HORIZONTAL $CC_VERTICAL $CC_TOP $CC_BOTTOM $CC_LEFT $CC_RIGHT);
-%Chart::Clicker::Drawing::EXPORT_TAGS = ( common => \@Chart::Clicker::Drawing::EXPORT_OK );
+@Chart::Clicker::Drawing::EXPORT_OK = qw(
+    $CC_HORIZONTAL $CC_VERTICAL $CC_TOP $CC_BOTTOM $CC_LEFT $CC_RIGHT $CC_CENTER
+);
+%Chart::Clicker::Drawing::EXPORT_TAGS = (
+    common => \@Chart::Clicker::Drawing::EXPORT_OK
+);
 
 our $CC_HORIZONTAL = 0;
 our $CC_VERTICAL = 1;
@@ -13,6 +17,7 @@ our $CC_TOP = 2;
 our $CC_BOTTOM = 3;
 our $CC_LEFT = 4;
 our $CC_RIGHT = 5;
+our $CC_CENTER = 6;
 
 =head1 NAME
 
